@@ -1,5 +1,5 @@
-initPrep <- function(data,rspNm,Anm,Bnm=NULL,sumFnNm,
-                     type,expo,rsteps,r) {
+initPrep <- function(data,rspNm,Anm,Bnm=NULL,sumFnNm,f,f1,
+                     fargs,type,expo,rsteps,r) {
 #
 # Function to prepare a list whose entries correspond to the
 # model cells and are (or are interpretable as) summary functions
@@ -70,12 +70,16 @@ if(inherits(data[,rspNm,drop=TRUE],"ppplist")) {
 if(bldSumFns) {
     if(requireNamespace("spatstat.geom")) {
         mikes <- data[,rspNm,drop=TRUE]
+        if(sumFnNm == "Kmark") {
+            ok <- checkMarksOK(mikes) # ok is always TRUE, otherwise an
+                                      # error would have been thrown
+        }
         wts   <- sapply(mikes,spatstat.geom::npoints)
         if(any(wts==0)) stop("Some point patterns in \"data\" are empty.\n")
         wts   <- wts^expo
         sumFn <- get(sumFnNm)
         if(is.null(r)) {
-        Let   <- if(sumFnNm=="Kest") "K" else "F"
+        Let <- if(sumFnNm %in% c("Kest","Kmark")) "K" else "F"
             if(requireNamespace("spatstat.explore")) {
                 rtop  <- min(sapply(mikes,function(x){
                              spatstat.explore::rmax.rule(Let,
@@ -85,7 +89,7 @@ if(bldSumFns) {
             }
             r <- seq(0,rtop,length=rsteps+1)
         }
-        sFraw  <- lapply(mikes,sumFn,r=r)
+        sFraw  <- lapply(mikes,sumFn,r=r,f=f,f1=f1,fargs=fargs)
         sumFns <- lapply(sFraw,function(x){x[[attr(x,"valu")]]})
     } else {
         stop("Required package \"spatstat.geom\" is not available.\n")
